@@ -3,9 +3,9 @@ use warnings;
 use strict;
 require Exporter;
 use base qw(Exporter);
-our @EXPORT_OK = qw/strip_diacritics fast_strip/;
+our @EXPORT_OK = qw/strip_diacritics strip_alphabet fast_strip/;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 use Unicode::UCD 'charinfo';
 use Encode 'decode_utf8';
 use utf8;
@@ -53,6 +53,50 @@ sub decompose
     return decompose ($character);
 }
 
+sub strip_alphabet
+{
+    my ($diacritics_text, %options) = @_;
+    my %swaps;
+    if (! defined $diacritics_text || length ($diacritics_text) == 0) {
+	return ($diacritics_text, {});
+    }
+    my @characters = split //, $diacritics_text;
+    my %alphabet;
+    for my $c (@characters) {
+	$alphabet{$c} = 1;
+    }
+    my @c = keys %alphabet;
+
+    for my $character (@c) {
+	# Reject non-word characters
+	if ($character !~ /\w/) {
+	    if ($options{verbose}) {
+		print "Not altering non-word character '$character'.\n";
+	    }
+	    next;
+	}
+	my $decomposed = decompose ($character, %options);
+	if ($character ne $decomposed) {
+	    my $boo = "$decomposed baba";
+	    $swaps{$character} = $boo;
+	    $swaps{$character} =~ s/ baba$//;
+	}
+    }
+
+    # Make the version of the text with all the diacritics removed.
+
+    my $stripped_text = $diacritics_text;
+    for my $k (keys %swaps) {
+	if ($options{verbose}) {
+	    printf "Swapping $k for $swaps{$k} (%X).\n", ord ($swaps{$k});
+	}
+	$stripped_text =~ s/$k/$swaps{$k}/g;
+    }
+    return ($stripped_text, \%swaps);
+}
+
+# Decompose one character. This is the core part of the program.
+
 sub fast_strip
 {
     my ($word) = @_;
